# SQLAlchemy Morphic

For use with Flask-SQLAlchemy and SQLAlchemy projects.


Flask SQLAlchemy query string morph helper. Translates query strings into base query modifications

## Installation

```
pip install SQLAlchemy-Morphic
```
## Basic Usage

## Available Morphs

|:Argument String|Example Values|
|---|---|
|...|...|
|...|...|
|...|...|
|...|...|
